@@ -1,5 +1,5 @@
 #   Download qualtrics data into R
-#    Copyright (C) 2017 Jasper Ginn
+#    Copyright (C) 2018 Jasper Ginn
 
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -18,9 +18,7 @@
 #'
 #' @seealso See \url{https://api.qualtrics.com/docs} for documentation on the Qualtrics API.
 #' @author Jasper Ginn
-#' @importFrom httr GET
-#' @importFrom httr content
-#' @importFrom httr add_headers
+#' @importFrom dplyr bind_rows
 #' @export
 #' @examples
 #' \dontrun{
@@ -63,5 +61,6 @@ getSurveys <- function() {
     master <- append(master, resp$result$elements)
   }
   # Bind to one large data frame & return
-  return(do.call(rbind.data.frame, master))
+  d <- bind_rows(master)
+  return(d)
 }
