@@ -1,4 +1,4 @@
-library(testthat)
+library(httptest)
 library(qualtRics)
 
 test_check("qualtRics")
